<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="600px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="上级分支:" prop="parentId" >
          <el-tree-select
              v-model="state.form.parentId"
              :data="state.menuOptions"
              :props="{ value: 'id', label: 'name', children: 'children' }"
              value-key="id"
              placeholder="上级分支"
              check-strictly
              style="width: 100%"
          />
        </el-form-item>
        <el-form-item label="序号:" prop="number">
          <el-input v-model.trim="state.form.number" :disabled="state.title =='查看'" placeholder="序号"></el-input>
        </el-form-item>

        <el-form-item label="目录名称:" prop="mess">
          <el-input v-model.trim="state.form.mess" :disabled="state.title =='查看'" placeholder="目录名称"></el-input>
        </el-form-item>
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import {ElMessage} from "element-plus";
import {addCatalogue, editCatalogue, getCatalogue} from "@/api/qualityManage/catalog";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()
const state = reactive({
  title: '',
  form: {
    id: null,
    mess: '',
    number:'',
    parentId: null,
    companyId: null
  },
  formRules:{
    mess: [{ required: true, message: '请输入目录名称', trigger: 'blur' }],
    number: [{ required: true, message: '请输入序号', trigger: 'blur' }],
    parentId:[{ required: true, message: '请选择上级分支', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  menuOptions: [],

})
onMounted(() => {

});

const openDialog = async (type, value,companyId, isAdmin,flag) => {
  state.isAdmin = isAdmin

  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
  if(state.title == '新增' && flag == 2){
    state.form.parentId = value.id

  }else if(state.title == '新增' && flag == 1 ){

    state.form.parentId = 0

  }
  if(state.title == '编辑'||state.title == '查看'){
    Object.keys(state.form).forEach(key => {
      if (key in value) {
        state.form[key] = value[key]
      }
    })
  }
  state.form.companyId = companyId

    await getTreeselect()

  dialogVisible.value = true
}


const onSubmit = async () => {
  const valid = await superRef.value.validate();
  console.log('state.form',state.form)
  if(valid){
    if(state.title == '新增'){
      const {id,...data} = state.form
      data.type = 2
      const res = await addCatalogue(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const {...data} = state.form
      data.type = 2
      const res = await editCatalogue(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}
const getTreeselect =async ()=> {
  state.menuOptions = [];
  const param = {
    type: 2,
    companyId: state.form.companyId
  }
  const res = await getCatalogue(param)
  if(res.code == 200){
    const menu = { id: 0, name: "主目录", children: [] };
    menu.children = await handleTree(res.data.data)
    state.menuOptions.push(menu);
  }else{
    ElMessage.warning(res.message)
  }
}

const handleTree = (val) => {
  const traverse = (nodes, currentPath = '') => {
    nodes.forEach((node, index) => {
      node.name = `${node.number} ${node.mess}`;
      // 递归处理子节点（传递当前序号路径）
      if (node.children && node.children.length) {
        traverse(node.children, node.number);
      }
    });
  };
  traverse(val); // 从根节点开始遍历
  return val;
}
const handleClose = () => {
  state.form = {
    id: null,
    mess: '',
    number:'',
    parentId: null,
    companyId: null
  }
  state.isTree = false
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
